@@ -1,5 +1,5 @@
 package Bitcoin::Crypto::BIP44;
-$Bitcoin::Crypto::BIP44::VERSION = '1.006';
+$Bitcoin::Crypto::BIP44::VERSION = '1.007';
 use v5.10;
 use strict;
 use warnings;
@@ -8,6 +8,7 @@ use Types::Standard qw(Enum Bool);
 use Types::Common::Numeric qw(PositiveOrZeroInt);
 use Scalar::Util qw(blessed);
 
+use Bitcoin::Crypto::Types qw(BIP44Purpose);
 use Bitcoin::Crypto::Network;
 use Bitcoin::Crypto::Exception;
 
@@ -28,7 +29,7 @@ use namespace::clean;
 
 has 'purpose' => (
 	is => 'ro',
-	isa => Enum [44, 49, 84],
+	isa => BIP44Purpose,
 	default => sub { 44 },
 );
 
@@ -77,6 +78,12 @@ has 'get_account' => (
 	default => sub { 0 },
 );
 
+has 'get_from_account' => (
+	is => 'ro',
+	isa => Bool,
+	default => sub { 0 },
+);
+
 use overload
 	q{""} => "as_string",
 	fallback => 1;
@@ -94,6 +101,9 @@ sub as_string
 	return $path
 		if $self->get_account;
 
+	$path = 'm'
+		if $self->get_from_account;
+
 	return sprintf "%s/%u/%u",
 		$path, $self->change, $self->index;
 }
@@ -172,7 +182,13 @@ By default, the value C<0> is used.
 
 =head2 get_account
 
-If passed C<1>, the resulting derivation path will only go as far as to the account part. L</index> and L</change> values will be ignored.
+If passed C<1>, the resulting derivation path will only go as far as to the account part. L</index> and L</change> values will be ignored. Use this to get extended key for the account.
+
+By default, you will get the full derivation path.
+
+=head2 get_from_account
+
+If passed C<1>, the resulting derivation path will start after the account part. L</purpose>, L</coin_type> and L</account> values will be ignored. Use this to further derive key that was only derived up to the account part.
 
 By default, you will get the full derivation path.
 
