@@ -1,5 +1,5 @@
 package Bitcoin::Crypto::Network;
-$Bitcoin::Crypto::Network::VERSION = '1.006';
+$Bitcoin::Crypto::Network::VERSION = '1.007';
 use v5.10;
 use strict;
 use warnings;
@@ -63,6 +63,30 @@ has "extpub_version" => (
 	required => 0,
 );
 
+has "extprv_compat_version" => (
+	is => "ro",
+	isa => Int,
+	required => 0,
+);
+
+has "extpub_compat_version" => (
+	is => "ro",
+	isa => Int,
+	required => 0,
+);
+
+has "extprv_segwit_version" => (
+	is => "ro",
+	isa => Int,
+	required => 0,
+);
+
+has "extpub_segwit_version" => (
+	is => "ro",
+	isa => Int,
+	required => 0,
+);
+
 has "bip44_coin" => (
 	is => "ro",
 	isa => Int,
@@ -95,6 +119,13 @@ sub set_default
 	return $self;
 }
 
+sub supports_segwit
+{
+	my ($self) = @_;
+
+	return defined $self->segwit_hrp;
+}
+
 sub find
 {
 	my ($class, $sub) = @_;
@@ -135,10 +166,18 @@ __PACKAGE__->register(
 	name => "Bitcoin Mainnet",
 	p2pkh_byte => "\x00",
 	p2sh_byte => "\x05",
-	segwit_hrp => "bc",
 	wif_byte => "\x80",
+	segwit_hrp => "bc",
+
 	extprv_version => 0x0488ade4,
 	extpub_version => 0x0488b21e,
+
+	extprv_compat_version => 0x049d7878,
+	extpub_compat_version => 0x049d7cb2,
+
+	extprv_segwit_version => 0x04b2430c,
+	extpub_segwit_version => 0x04b24746,
+
 	bip44_coin => 0,
 )->set_default;
 
@@ -147,10 +186,18 @@ __PACKAGE__->register(
 	name => "Bitcoin Testnet",
 	p2pkh_byte => "\x6f",
 	p2sh_byte => "\xc4",
-	segwit_hrp => "tb",
 	wif_byte => "\xef",
+	segwit_hrp => "tb",
+
 	extprv_version => 0x04358394,
 	extpub_version => 0x043587cf,
+
+	extprv_compat_version => 0x044a4e28,
+	extpub_compat_version => 0x044a5262,
+
+	extprv_segwit_version => 0x045f18bc,
+	extpub_segwit_version => 0x045f1cf6,
+
 	bip44_coin => 1,
 );
 
@@ -162,8 +209,10 @@ __PACKAGE__->register(
 	p2pkh_byte => "\x1e",
 	p2sh_byte => "\x16",
 	wif_byte => "\x9e",
+
 	extprv_version => 0x02fac398,
 	extpub_version => 0x02facafd,
+
 	bip44_coin => 3,
 );
 
@@ -173,8 +222,10 @@ __PACKAGE__->register(
 	p2pkh_byte => "\x71",
 	p2sh_byte => "\xc4",
 	wif_byte => "\xf1",
+
 	extprv_version => 0x04358394,
 	extpub_version => 0x043587cf,
+
 	bip44_coin => 1,
 );
 
@@ -274,9 +325,15 @@ Right now networks only require four keys, which are marked with C<(*)>
 		wif_byte       => "(*) WIF private key prefix byte, eg. 0x80",
 		p2sh_byte      => "p2sh address prefix byte, eg. 0x05",
 		segwit_hrp     => "segwit native address human readable part, eg. 'bc'",
-		extprv_version => "version of extended private keys, eg. 0x0488ade4",
-		extpub_version => "version of extended public keys, eg. 0x0488b21e",
-		bip44_coin     => "bip44 coin number, eg. 0",
+
+		extprv_version        => "version prefix of serialized extended private keys, eg. 0x0488ade4",
+		extpub_version        => "version prefix of serialized extended public keys, eg. 0x0488b21e",
+		extprv_compat_version => "same as extprv_version, but for BIP49",
+		extpub_compat_version => "same as extpub_version, but for BIP49",
+		extprv_segwit_version => "same as extprv_version, but for BIP84",
+		extpub_segwit_version => "same as extpub_version, but for BIP84",
+
+		bip44_coin => "bip44 coin number, eg. 0",
 	);
 
 After you register a network with this hashref your program will be able to import keys for that
@@ -311,6 +368,12 @@ Sets the network as default one. All newly created private and public keys will
 
 Returns the network instance.
 
+=head2 supports_segwit
+
+	$bool = $object->supports_segwit()
+
+Returns a boolean which can be used to determine whether a given network has segwit configured.
+
 =head2 new
 
 	$network_object = $class->new(%config)
