@@ -1,5 +1,5 @@
 package Bitcoin::Crypto::Role::Key;
-$Bitcoin::Crypto::Role::Key::VERSION = '1.006';
+$Bitcoin::Crypto::Role::Key::VERSION = '1.007';
 use v5.10;
 use strict;
 use warnings;
@@ -7,6 +7,7 @@ use Types::Standard qw(InstanceOf);
 use Crypt::PK::ECC;
 use Scalar::Util qw(blessed);
 
+use Bitcoin::Crypto::Types qw(BIP44Purpose);
 use Bitcoin::Crypto::Config;
 use Bitcoin::Crypto::Util qw(get_key_type);
 use Bitcoin::Crypto::Helpers qw(ensure_length);
@@ -21,6 +22,14 @@ has "key_instance" => (
 	required => 1,
 );
 
+has 'purpose' => (
+	is => 'ro',
+	isa => BIP44Purpose,
+	writer => '_set_purpose',
+	predicate => 'has_purpose',
+	required => 0,
+);
+
 sub _is_private { undef }
 
 sub _build_args
@@ -73,6 +82,13 @@ sub _create_key
 	return $key;
 }
 
+sub set_purpose
+{
+	my ($self, $purpose) = @_;
+	$self->_set_purpose($purpose)
+		if $purpose;
+}
+
 sub raw_key
 {
 	my ($self, $type) = @_;
