@@ -1,5 +1,5 @@
 package Bitcoin::Crypto::Script;
-$Bitcoin::Crypto::Script::VERSION = '1.006';
+$Bitcoin::Crypto::Script::VERSION = '1.007';
 use v5.10;
 use strict;
 use warnings;
@@ -363,6 +363,11 @@ sub get_compat_address
 {
 	my ($self) = @_;
 
+	# network field is not required, lazy check for completeness
+	Bitcoin::Crypto::Exception::NetworkConfig->raise(
+		"this network does not support segregated witness"
+	) unless $self->network->supports_segwit;
+
 	my $program = Bitcoin::Crypto::Script->new(network => $self->network);
 	$program->add_operation("OP_" . Bitcoin::Crypto::Config::witness_version)
 		->push_bytes(sha256($self->get_script));
@@ -375,8 +380,8 @@ sub get_segwit_address
 
 	# network field is not required, lazy check for completeness
 	Bitcoin::Crypto::Exception::NetworkConfig->raise(
-		"no segwit_hrp found in network configuration"
-	) unless defined $self->network->segwit_hrp;
+		"this network does not support segregated witness"
+	) unless $self->network->supports_segwit;
 
 	return encode_segwit($self->network->segwit_hrp, $self->witness_program);
 }
