@@ -1,12 +1,12 @@
 package Bitcoin::Crypto::Types;
-$Bitcoin::Crypto::Types::VERSION = '1.006';
+$Bitcoin::Crypto::Types::VERSION = '1.007';
 use v5.10;
 use strict;
 use warnings;
 use Type::Library -base;
 use Type::Coercion;
 use Types::Common::Numeric qw(assert_PositiveInt);
-use Types::Standard qw(Int InstanceOf);
+use Types::Standard qw(Int InstanceOf Enum);
 
 BEGIN {
 	require Math::BigInt;
@@ -20,6 +20,11 @@ BEGIN {
 	}
 }
 
+__PACKAGE__->add_type(
+	name => "BIP44Purpose",
+	parent => Enum->of(44, 49, 84),
+);
+
 __PACKAGE__->add_type(
 	name => "IntMaxBits",
 	parent => InstanceOf->of("Math::BigInt"),
